##########################################################################################################
### R code for Simulation Studies----Model selection in Section 5.2
### MA and MCDERMOTT Generalized Multiple Contrast Tests in Dose-Response Studies
### Table 4, Model selection of MCP-Mod, Tippett, Fisher and Inverse normal
### The reference set is determined by the adjusted p-value or closure adjusted p-value in CTP
### Using the raw p value to order the reference set
### Only consider the narrower candidate set of models in Bretz et al (2005) 
### R program written by Shiyang Ma at 2018-12-06
##########################################################################################################

### Simulation studies were conducted using R studio version: 3.5.0 under BlueHive system, 
### a Linux cluster provided by the Center for Integrated Research Computing (CIRC) at the University of Rochester.
### Random numbers were generated using R package 'mvtnorm' version 1.0-8.
### Please note that different versions of R studio might generate slightly different simulation results since the
### R package 'mvtnorm' might have different version and thus have different random number generators even for the
### same seed. But the difference should be negligible (within simulation error). 

########Using the same simulation setting at Bretz et al 2005 simulation studies ##################
library("mvtnorm")

d=c(0,0.05, 0.2, 0.6, 1)
#Only consider 6 data generating dose-response shapes in the candidate set:
#Emax, L-L, Linear, E1, Q1, Logistic
#Emax
mu1=0.2+0.7*d/(0.2+d)
#Linear in log-dose
mu2=0.2+0.6*log(5*d+1)/log(6)
#Linear
mu3=0.2+0.6*d
#Exponential 1
mu4=0.183+0.017*exp(2*d*log(6))
#Quadratic 1
mu5=0.2+2.049*d-1.749*d^2
#Logistic
mu6=0.193+0.607/(1+exp(10*log(3)*(0.4-d)))

mu_gen=cbind(mu1,mu2,mu3,mu4,mu5,mu6)

#Contrasts of 6 candidate models: 
contrast=function(mu){
   (mu-mean(mu))/norm(mu-mean(mu),type='2')
}
c1=contrast(mu1) #Emax
c2=contrast(mu2) #L-L 
c3=contrast(mu3) #Linear
c4=contrast(mu4) #E1
c5=contrast(mu5) #Q1
c6=contrast(mu6)  #logistic

rho12=sum(c1*c2)/sqrt(sum(c1^2)*sum(c2^2))
rho13=sum(c1*c3)/sqrt(sum(c1^2)*sum(c3^2))
rho14=sum(c1*c4)/sqrt(sum(c1^2)*sum(c4^2))
rho15=sum(c1*c5)/sqrt(sum(c1^2)*sum(c5^2))
rho16=sum(c1*c6)/sqrt(sum(c1^2)*sum(c6^2))

rho23=sum(c2*c3)/sqrt(sum(c2^2)*sum(c3^2))
rho24=sum(c2*c4)/sqrt(sum(c2^2)*sum(c4^2))
rho25=sum(c2*c5)/sqrt(sum(c2^2)*sum(c5^2))
rho26=sum(c2*c6)/sqrt(sum(c2^2)*sum(c6^2))

rho34=sum(c3*c4)/sqrt(sum(c3^2)*sum(c4^2))
rho35=sum(c3*c5)/sqrt(sum(c3^2)*sum(c5^2))
rho36=sum(c3*c6)/sqrt(sum(c3^2)*sum(c6^2))

rho45=sum(c4*c5)/sqrt(sum(c4^2)*sum(c5^2))
rho46=sum(c4*c6)/sqrt(sum(c4^2)*sum(c6^2))
rho56=sum(c5*c6)/sqrt(sum(c5^2)*sum(c6^2))

Sigma=matrix(c(1,rho12, rho13,rho14,rho15, rho16,
               rho12, 1, rho23, rho24,rho25,  rho26,
               rho13, rho23, 1, rho34, rho35,  rho36,
               rho14, rho24, rho34, 1, rho45,  rho46,
               rho15, rho25, rho35, rho45, 1,  rho56,
               rho16, rho26, rho36, rho46,  rho56, 1
),nrow=6,ncol=6)

##Indicator for all 2^6-1=63 subset intersections of Closed Testing Procedure (CTP)
Ind=matrix(0,nrow=6,ncol=63)
#col1 of Ind Step1
combn(1:6,6)  
Ind[combn(1:6,6),1]=1
#col 2 to 7 of Ind Step2
choose(6, 5)
for (i in 1:choose(6, 5)){
   Ind[,(choose(6, 6)+1):(choose(6, 6)+choose(6, 5))][combn(1:6,5)[,i],i]=1
}
#col 8 to 22 of Ind Step3
choose(6, 4)
for (i in 1:choose(6, 4)){
   Ind[,(choose(6, 6)+choose(6, 5)+1):(choose(6, 6)+choose(6, 5)+choose(6, 4))][combn(1:6,4)[,i],i]=1
}
#col 23 to 42 of Ind Step4
choose(6, 3)
for (i in 1:choose(6, 3)){
   Ind[,(choose(6, 6)+choose(6, 5)+choose(6, 4)+1):
          (choose(6, 6)+choose(6, 5)+choose(6, 4)+choose(6, 3))][combn(1:6,3)[,i],i]=1
}
#col 43 to 57 of Ind Step5
choose(6, 2)
for (i in 1:choose(6, 2)){
   Ind[,(choose(6, 6)+choose(6, 5)+choose(6, 4)+choose(6, 3)+1):
          (choose(6, 6)+choose(6, 5)+choose(6, 4)+choose(6, 3)+choose(6, 2))][combn(1:6,2)[,i],i]=1
}
#col 58 to 63 of Ind Step6
choose(6, 1)
for (i in 1:choose(6, 1)){
   Ind[,(choose(6, 6)+choose(6, 5)+choose(6, 4)+choose(6, 3)+choose(6, 2)+1):
          (choose(6, 6)+choose(6, 5)+choose(6, 4)+choose(6, 3)+choose(6, 2)+choose(6, 1))][combn(1:6,1)[,i],i]=1
}


#############################################################################################
#Write a modeling function to conduct model selection:
modeling=function(nsim=10000, n=10, mu=mu_gen[,1], sigma=0.65){
   
   set.seed(12345)  
   ddf=n*5-5  
   #Model selected for each procedure  
   model_sel_MCPMod=rep(NA,nsim)
   model_sel_T=rep(NA,nsim)
   model_sel_F=rep(NA,nsim)
   model_sel_N=rep(NA,nsim)
   #Candidate set
   candidate=c('Emax','L-L', 'Lin', 'E', 'Q', 'Logist')
   for (s in 1:nsim){
      
      #generate data with 5 dose group, sigma=1.478
      Y=rmvnorm(n,mean=mu,sigma = diag(sigma^2,nrow=5,ncol=5))
      #Response
      resp=c(Y[,1], Y[,2],Y[,3], Y[,4],Y[,5])
      dose=c(rep(0,n),rep(0.05,n),rep(0.2,n),rep(0.6,n),rep(1,n))
      #Multiple contrast test
      ybar1=mean(resp[dose==0])
      ybar2=mean(resp[dose==0.05])
      ybar3=mean(resp[dose==0.2])
      ybar4=mean(resp[dose==0.6])
      ybar5=mean(resp[dose==1])
      ybar=c(ybar1,ybar2,ybar3,ybar4,ybar5)
      
      #contrast estimate of 6 models
      ce1=sum(c1*ybar)
      ce2=sum(c2*ybar)  
      ce3=sum(c3*ybar)
      ce4=sum(c4*ybar)
      ce5=sum(c5*ybar)
      ce6=sum(c6*ybar)
      ce=c(ce1,ce2,ce3,ce4,ce5,ce6)
      
      #T-value
      S2=(sum((resp[dose==0]-ybar1)^2)+sum((resp[dose==0.05]-ybar2)^2)+
             sum((resp[dose==0.2]-ybar3)^2)+sum((resp[dose==0.6]-ybar4)^2)+
             sum((resp[dose==1]-ybar5)^2))/ddf
      t1=ce1/sqrt(S2*sum(c1^2)/n)
      t2=ce2/sqrt(S2*sum(c2^2)/n)
      t3=ce3/sqrt(S2*sum(c3^2)/n)
      t4=ce4/sqrt(S2*sum(c4^2)/n)
      t5=ce5/sqrt(S2*sum(c5^2)/n)
      t6=ce6/sqrt(S2*sum(c6^2)/n)
      t=c(t1,t2,t3,t4,t5,t6)
      
      #Dependent p values
      p1=pt(t1,df=ddf,lower.tail = F)
      p2=pt(t2,df=ddf,lower.tail = F)
      p3=pt(t3,df=ddf,lower.tail = F)
      p4=pt(t4,df=ddf,lower.tail = F)
      p5=pt(t5,df=ddf,lower.tail = F)
      p6=pt(t6,df=ddf,lower.tail = F)
      p=c(p1,p2,p3,p4,p5,p6)
      
#################################### MCP-Mod###############################################################
      
      padj1_MCPMod=1-pmvt(lower=rep(-Inf,6),upper =rep(t1,6), corr=Sigma, df=ddf)[1]
      padj2_MCPMod=1-pmvt(lower=rep(-Inf,6),upper =rep(t2,6), corr=Sigma, df=ddf)[1]
      padj3_MCPMod=1-pmvt(lower=rep(-Inf,6),upper =rep(t3,6), corr=Sigma, df=ddf)[1]
      padj4_MCPMod=1-pmvt(lower=rep(-Inf,6),upper =rep(t4,6), corr=Sigma, df=ddf)[1]
      padj5_MCPMod=1-pmvt(lower=rep(-Inf,6),upper =rep(t5,6), corr=Sigma, df=ddf)[1]
      padj6_MCPMod=1-pmvt(lower=rep(-Inf,6),upper =rep(t6,6), corr=Sigma, df=ddf)[1]
      padj_MCPMod=c(padj1_MCPMod,padj2_MCPMod,padj3_MCPMod,padj4_MCPMod,padj5_MCPMod,padj6_MCPMod)
      
      if(min(padj_MCPMod)<0.05){
         #There is a signal of dose-response relationship
         refer_MCPMod=candidate[padj_MCPMod<0.05] 
         #Ordered reference sets using raw p-value:
         refer_order_MCPMod=refer_MCPMod[order(p[padj_MCPMod<0.05],decreasing =FALSE)]
         #Selece the first model in ordered reference set
         model_sel_MCPMod[s]=refer_order_MCPMod[1]
      } 
#######################################Tippett ##############################################################     
      
      allp_T=rep(NA,63)
      allp_T[1]=min(padj_MCPMod)
      if(allp_T[1]<0.05){
         #There is a signal of dose-response relationship
         #Closure adjusted p-value of Closed testing procedure
         for (i in 2:57) {
            t_ind=(Ind[,i]*c(1,2,3,4,5,6))[Ind[,i]*c(1,2,3,4,5,6)>0]
            tt=(t*Ind[,i])[Ind[,i]>0]
            Sigmaa=Sigma[t_ind,t_ind]
            allp_T[i]=1-pmvt(lower=rep(-Inf,sum(Ind[,i])),upper =rep(max(tt),sum(Ind[,i])), corr=Sigmaa, df=ddf)[1]
         }
         allp_T[58:63]=p
         
         p1_adj_T=max(allp_T[Ind[1,]==1])
         p2_adj_T=max(allp_T[Ind[2,]==1])
         p3_adj_T=max(allp_T[Ind[3,]==1])
         p4_adj_T=max(allp_T[Ind[4,]==1])
         p5_adj_T=max(allp_T[Ind[5,]==1])
         p6_adj_T=max(allp_T[Ind[6,]==1])
         p_adj_T=c(p1_adj_T,p2_adj_T,p3_adj_T,p4_adj_T,p5_adj_T,p6_adj_T)
         
         refer_T=candidate[p_adj_T<0.05] 
         #Ordered reference sets using raw p-value:
         refer_order_T=refer_T[order(p[p_adj_T<0.05],decreasing =FALSE)]
         
         if (length(refer_order_T)==0) {
            model_sel_T[s]='NA2' #NA2 is p123456<=0.05, but all of the adjusted p value >0.05
         } else {
         #Selece the model in reference set that have laegest t value
         model_sel_T[s]=refer_order_T[1]
         }
      }
#######################################Fisher ##############################################################      
      cov12_F=3.279*rho12+0.711*rho12^2+0.727/ddf+0.129*rho12/ddf-0.768*rho12^2/ddf
      cov13_F=3.279*rho13+0.711*rho13^2+0.727/ddf+0.129*rho13/ddf-0.768*rho13^2/ddf
      cov14_F=3.279*rho14+0.711*rho14^2+0.727/ddf+0.129*rho14/ddf-0.768*rho14^2/ddf
      cov15_F=3.279*rho15+0.711*rho15^2+0.727/ddf+0.129*rho15/ddf-0.768*rho15^2/ddf
      cov16_F=3.279*rho16+0.711*rho16^2+0.727/ddf+0.129*rho16/ddf-0.768*rho16^2/ddf
      
      cov23_F=3.279*rho23+0.711*rho23^2+0.727/ddf+0.129*rho23/ddf-0.768*rho23^2/ddf
      cov24_F=3.279*rho24+0.711*rho24^2+0.727/ddf+0.129*rho24/ddf-0.768*rho24^2/ddf
      cov25_F=3.279*rho25+0.711*rho25^2+0.727/ddf+0.129*rho25/ddf-0.768*rho25^2/ddf
      cov26_F=3.279*rho26+0.711*rho26^2+0.727/ddf+0.129*rho26/ddf-0.768*rho26^2/ddf
      
      cov34_F=3.279*rho34+0.711*rho34^2+0.727/ddf+0.129*rho34/ddf-0.768*rho34^2/ddf
      cov35_F=3.279*rho35+0.711*rho35^2+0.727/ddf+0.129*rho35/ddf-0.768*rho35^2/ddf
      cov36_F=3.279*rho36+0.711*rho36^2+0.727/ddf+0.129*rho36/ddf-0.768*rho36^2/ddf
      
      cov45_F=3.279*rho45+0.711*rho45^2+0.727/ddf+0.129*rho45/ddf-0.768*rho45^2/ddf
      cov46_F=3.279*rho46+0.711*rho46^2+0.727/ddf+0.129*rho46/ddf-0.768*rho46^2/ddf
      cov56_F=3.279*rho56+0.711*rho56^2+0.727/ddf+0.129*rho56/ddf-0.768*rho56^2/ddf
      
      #The mean and variance of the Fisher's statistic 
      E=2*6
      var=4*6+2*(cov12_F+cov13_F+cov14_F+cov15_F+cov16_F+
                    cov23_F+cov24_F+cov25_F+cov26_F+
                    cov34_F+cov35_F+cov36_F+
                    cov45_F+cov46_F+
                    cov56_F)
      #Degrees of freedom f  
      f=2*E^2/var
      c=var/(2*E)
      phiFobs=-2*(log(p1)+log(p2)+log(p3)+log(p4)+log(p5)+log(p6))
      
      if(pchisq(phiFobs/c,df=f,lower.tail =FALSE)<=0.05){
         #There is a signal of dose-response relationship
         #Model selction of Fisher's combination method
         
         cov_F=matrix(0, nrow=6, ncol=6)
         cov_F[1,2]=cov12_F
         cov_F[1,3]=cov13_F
         cov_F[1,4]=cov14_F
         cov_F[1,5]=cov15_F
         cov_F[1,6]=cov16_F
         
         cov_F[2,3]=cov23_F
         cov_F[2,4]=cov24_F
         cov_F[2,5]=cov25_F
         cov_F[2,6]=cov26_F
         
         cov_F[3,4]=cov34_F
         cov_F[3,5]=cov35_F
         cov_F[3,6]=cov36_F
         
         cov_F[4,5]=cov45_F
         cov_F[4,6]=cov46_F
         cov_F[5,6]=cov56_F
         
         #Closure adjusted p-value of Fisher
         allp_F=rep(NA,63)
         for (i in 1:57) {
            p_ind=(Ind[,i]*c(1,2,3,4,5,6))[Ind[,i]*c(1,2,3,4,5,6)>0]
            psi_F_obs=-2*(sum(log((p*Ind[,i])[Ind[,i]>0])))
            E=2*sum(Ind[,i])
            sum=0
            for (d in 1:dim(combn(p_ind,2))[2] ) {
               sum=sum+cov_F[combn(p_ind,2)[1,d],combn(p_ind,2)[2,d]]
            }
            sum
            var=4*sum(Ind[,i])+2*sum
            f=2*E^2/var
            c=var/(2*E)
            allp_F[i]= pchisq(psi_F_obs/c,df=f,lower.tail = FALSE)
         }
         allp_F[58:63]=p
 
         p1_adj_F=max(allp_F[Ind[1,]==1])
         p2_adj_F=max(allp_F[Ind[2,]==1])
         p3_adj_F=max(allp_F[Ind[3,]==1])
         p4_adj_F=max(allp_F[Ind[4,]==1])
         p5_adj_F=max(allp_F[Ind[5,]==1])
         p6_adj_F=max(allp_F[Ind[6,]==1])
         p_adj_F=c(p1_adj_F,p2_adj_F,p3_adj_F,p4_adj_F,p5_adj_F,p6_adj_F)
         
         refer_F=candidate[p_adj_F<=0.05] 
         #Ordered reference sets:
         refer_order_F=refer_F[order(p[p_adj_F<=0.05],decreasing =FALSE)]
         
         if (length(refer_order_F)==0) {
               model_sel_F[s]='NA2' #NA2 is p123456<=0.05, but all of the adjusted p value >0.05
            } else {
             #Selece the model in reference set that have smallest adjusted p value
             model_sel_F[s]=refer_order_F[1]
            }
         }
      
######################################Inverse normal ##############################################
      cov12_N=rho12+0.00019*rho12^3-0.02378*rho12/ddf+0.01891*rho12^3/ddf
      cov13_N=rho13+0.00019*rho13^3-0.02378*rho13/ddf+0.01891*rho13^3/ddf
      cov14_N=rho14+0.00019*rho14^3-0.02378*rho14/ddf+0.01891*rho14^3/ddf
      cov15_N=rho15+0.00019*rho15^3-0.02378*rho15/ddf+0.01891*rho15^3/ddf
      cov16_N=rho16+0.00019*rho16^3-0.02378*rho16/ddf+0.01891*rho16^3/ddf
      
      cov23_N=rho23+0.00019*rho23^3-0.02378*rho23/ddf+0.01891*rho23^3/ddf
      cov24_N=rho24+0.00019*rho24^3-0.02378*rho24/ddf+0.01891*rho24^3/ddf
      cov25_N=rho25+0.00019*rho25^3-0.02378*rho25/ddf+0.01891*rho25^3/ddf
      cov26_N=rho26+0.00019*rho26^3-0.02378*rho26/ddf+0.01891*rho26^3/ddf
      
      cov34_N=rho34+0.00019*rho34^3-0.02378*rho34/ddf+0.01891*rho34^3/ddf
      cov35_N=rho35+0.00019*rho35^3-0.02378*rho35/ddf+0.01891*rho35^3/ddf
      cov36_N=rho36+0.00019*rho36^3-0.02378*rho36/ddf+0.01891*rho36^3/ddf
      
      cov45_N=rho45+0.00019*rho45^3-0.02378*rho45/ddf+0.01891*rho45^3/ddf
      cov46_N=rho46+0.00019*rho46^3-0.02378*rho46/ddf+0.01891*rho46^3/ddf
      cov56_N=rho56+0.00019*rho56^3-0.02378*rho56/ddf+0.01891*rho56^3/ddf
      
      pvalue_N=pnorm(1/sqrt(6)*(-qnorm(p1)-qnorm(p2)-qnorm(p3)-qnorm(p4)-qnorm(p5)-qnorm(p6)),mean=0,
                     sd=sqrt(1+2/6*(cov12_N+cov13_N+cov14_N+cov15_N+cov16_N+
                                       cov23_N+cov24_N+cov25_N+cov26_N+
                                       cov34_N+cov35_N+cov36_N+
                                       cov45_N+cov46_N+
                                       cov56_N) ),lower.tail = FALSE)
      
      if(pvalue_N<=0.05){
      #there is a signal of dose-response relationship
      # Model selction of inverse normal 
         cov_N=matrix(0, nrow=6, ncol=6)
         cov_N[1,2]=cov12_N
         cov_N[1,3]=cov13_N
         cov_N[1,4]=cov14_N
         cov_N[1,5]=cov15_N
         cov_N[1,6]=cov16_N
         
         cov_N[2,3]=cov23_N
         cov_N[2,4]=cov24_N
         cov_N[2,5]=cov25_N
         cov_N[2,6]=cov26_N
         
         cov_N[3,4]=cov34_N
         cov_N[3,5]=cov35_N
         cov_N[3,6]=cov36_N
         
         cov_N[4,5]=cov45_N
         cov_N[4,6]=cov46_N
         cov_N[5,6]=cov56_N
         
         #Closure adjusted p-value of Inverse normal
         allp_N=rep(NA,63)
         for (i in 1:57) {
            p_ind=(Ind[,i]*c(1,2,3,4,5,6))[Ind[,i]*c(1,2,3,4,5,6)>0]
            psi_N_obs=1/sqrt(sum(Ind[,i]))*sum(-qnorm((p*Ind[,i])[Ind[,i]>0]))
            sum=0
            for (d in 1:dim(combn(p_ind,2))[2] ) {
               sum=sum+cov_N[combn(p_ind,2)[1,d],combn(p_ind,2)[2,d]]
            }
            sum
            var=1+2/sum(Ind[,i])*sum
            allp_N[i]= pnorm(psi_N_obs,mean=0,sd=sqrt(var), lower.tail = FALSE)
         }
         allp_N[58:63]=p

         p1_adj_N=max(allp_N[Ind[1,]==1])
         p2_adj_N=max(allp_N[Ind[2,]==1])
         p3_adj_N=max(allp_N[Ind[3,]==1])
         p4_adj_N=max(allp_N[Ind[4,]==1])
         p5_adj_N=max(allp_N[Ind[5,]==1])
         p6_adj_N=max(allp_N[Ind[6,]==1])
         p_adj_N=c(p1_adj_N,p2_adj_N,p3_adj_N,p4_adj_N,p5_adj_N,p6_adj_N)
         
         refer_N=candidate[p_adj_N<=0.05] 
         #Ordered reference sets:
         refer_order_N=refer_N[order(p[p_adj_N<=0.05],decreasing =FALSE)]
         
         if (length(refer_order_N)==0) {
               model_sel_N[s]='NA2' #NA2 is p123456<=0.05, but all of the adjusted p value >0.05
         } else {
          #Selece the model in reference set that have smallest adjusted p value
          model_sel_N[s]=refer_order_N[1]
         }
      }
   }#End of simulation
   
   modeling=as.matrix(cbind(#Model selection
                            sum(model_sel_MCPMod=="Emax",na.rm=TRUE),
                            sum(model_sel_MCPMod=="L-L",na.rm=TRUE),
                            sum(model_sel_MCPMod=="Lin",na.rm=TRUE),
                            sum(model_sel_MCPMod=="E",na.rm=TRUE),
                            sum(model_sel_MCPMod=="Q",na.rm=TRUE),
                            sum(model_sel_MCPMod=="Logist",na.rm=TRUE),
                            sum(is.na(model_sel_MCPMod)),
                            
                            sum(model_sel_T=="Emax",na.rm=TRUE),
                            sum(model_sel_T=="L-L",na.rm=TRUE),
                            sum(model_sel_T=="Lin",na.rm=TRUE),
                            sum(model_sel_T=="E",na.rm=TRUE),
                            sum(model_sel_T=="Q",na.rm=TRUE),
                            sum(model_sel_T=="Logist",na.rm=TRUE),
                            sum(model_sel_T=="NA2",na.rm=TRUE),
                            sum(is.na(model_sel_T)),
                            
                            sum(model_sel_F=="Emax",na.rm=TRUE),
                            sum(model_sel_F=="L-L",na.rm=TRUE),
                            sum(model_sel_F=="Lin",na.rm=TRUE),
                            sum(model_sel_F=="E",na.rm=TRUE),
                            sum(model_sel_F=="Q",na.rm=TRUE),
                            sum(model_sel_F=="Logist",na.rm=TRUE),
                            sum(model_sel_F=="NA2",na.rm=TRUE),
                            sum(is.na(model_sel_F)),
                            
                            sum(model_sel_N=="Emax",na.rm=TRUE),
                            sum(model_sel_N=="L-L",na.rm=TRUE),
                            sum(model_sel_N=="Lin",na.rm=TRUE),
                            sum(model_sel_N=="E",na.rm=TRUE),
                            sum(model_sel_N=="Q",na.rm=TRUE),
                            sum(model_sel_N=="Logist",na.rm=TRUE),
                            sum(model_sel_N=="NA2",na.rm=TRUE),
                            sum(is.na(model_sel_N)) ))
   
colnames(modeling)=c('sel emax_M','sel L-L_MCP','sel Lin_MCP', 'sel E_MCP','sel Q_MCP', 'sel Logist_MCP', 'sel nothing_MCP',
                     'sel emax_T','sel L-L_T','sel Lin_T', 'sel E_T','sel Q_T', 'sel Logist_T', 'NA2_T','sel nothing_T',
                     'sel emax_F','sel L-L_F','sel Lin_F', 'sel E_F','sel Q_F', 'sel Logist_F', 'NA2_F','sel nothing_F',
                     'sel emax_N','sel L-L_N','sel Lin_N', 'sel E_N','sel Q_N', 'sel Logist_N', 'NA2_N','sel nothing_N')
   return(modeling)
}

############################################################################
### Conduct the simulation studies by running 6 parallel codes in Bluehive  
### Each one take around 8 hours                                         ###
############################################################################

###############################CODE 1 ######################################
start_time <- Sys.time()
n10g1=modeling(nsim=10000, n=10, mu=mu_gen[,1], sigma=0.65)
n10g1
n10g2=modeling(nsim=10000, n=10, mu=mu_gen[,2], sigma=0.65)
n10g2
n10g3=modeling(nsim=10000, n=10, mu=mu_gen[,3], sigma=0.65)
n10g3
n10g4=modeling(nsim=10000, n=10, mu=mu_gen[,4], sigma=0.65)
n10g4
n10g5=modeling(nsim=10000, n=10, mu=mu_gen[,5], sigma=0.65)
n10g5
n10g6=modeling(nsim=10000, n=10, mu=mu_gen[,6], sigma=0.65)
n10g6
end_time <- Sys.time()
#Running time 10.2 hours
end_time - start_time

results_mod_sel1=as.matrix(rbind(n10g1,n10g2,n10g3,n10g4,n10g5,n10g6))
rownames(results_mod_sel1)=c('n10Emax','n10L-L','n10Lin','n10E','n10Q','n10Log')
saveRDS(results_mod_sel1, file="results_mod_sel1.Rds")

###############################CODE 2 ##########################################
start_time <- Sys.time()
n25g1=modeling(nsim=10000, n=25, mu=mu_gen[,1], sigma=0.65)
n25g1
n25g2=modeling(nsim=10000, n=25, mu=mu_gen[,2], sigma=0.65)
n25g2
n25g3=modeling(nsim=10000, n=25, mu=mu_gen[,3], sigma=0.65)
n25g3
n25g4=modeling(nsim=10000, n=25, mu=mu_gen[,4], sigma=0.65)
n25g4
n25g5=modeling(nsim=10000, n=25, mu=mu_gen[,5], sigma=0.65)
n25g5
n25g6=modeling(nsim=10000, n=25, mu=mu_gen[,6], sigma=0.65)
n25g6
end_time <- Sys.time()
# Running time 8.85 hours
end_time - start_time

results_mod_sel2=as.matrix(rbind(n25g1,n25g2,n25g3,n25g4,n25g5,n25g6))
rownames(results_mod_sel2)=c('n25Emax','n25L-L','n25Lin','n25E','n25Q','n25Log')
saveRDS(results_mod_sel2, file="results_mod_sel2.Rds")

###############################CODE 3 ##########################################
start_time <- Sys.time()
n50g1=modeling(nsim=10000, n=50, mu=mu_gen[,1], sigma=0.65)
n50g1
n50g2=modeling(nsim=10000, n=50, mu=mu_gen[,2], sigma=0.65)
n50g2
n50g3=modeling(nsim=10000, n=50, mu=mu_gen[,3], sigma=0.65)
n50g3
n50g4=modeling(nsim=10000, n=50, mu=mu_gen[,4], sigma=0.65)
n50g4
n50g5=modeling(nsim=10000, n=50, mu=mu_gen[,5], sigma=0.65)
n50g5
n50g6=modeling(nsim=10000, n=50, mu=mu_gen[,6], sigma=0.65)
n50g6
end_time <- Sys.time()
# Running time 7.9 hours
end_time - start_time

results_mod_sel3=as.matrix(rbind(n50g1,n50g2,n50g3,n50g4,n50g5,n50g6))
rownames(results_mod_sel3)=c('n50Emax','n50L-L','n50Lin','n50E','n50Q','n50Log')
saveRDS(results_mod_sel3, file="results_mod_sel3.Rds")

###############################CODE 4 ##########################################
start_time <- Sys.time()
n75g1=modeling(nsim=10000, n=75, mu=mu_gen[,1], sigma=0.65)
n75g1
n75g2=modeling(nsim=10000, n=75, mu=mu_gen[,2], sigma=0.65)
n75g2
n75g3=modeling(nsim=10000, n=75, mu=mu_gen[,3], sigma=0.65)
n75g3
n75g4=modeling(nsim=10000, n=75, mu=mu_gen[,4], sigma=0.65)
n75g4
n75g5=modeling(nsim=10000, n=75, mu=mu_gen[,5], sigma=0.65)
n75g5
n75g6=modeling(nsim=10000, n=75, mu=mu_gen[,6], sigma=0.65)
n75g6
end_time <- Sys.time()
# Running time 7.9 hours
end_time - start_time

results_mod_sel4=as.matrix(rbind(n75g1,n75g2,n75g3,n75g4,n75g5,n75g6))
rownames(results_mod_sel4)=c('n75Emax','n75L-L','n75Lin','n75E','n75Q','n75Log')
saveRDS(results_mod_sel4, file="results_mod_sel4.Rds")

###############################CODE 5 ####################################################
start_time <- Sys.time()
n100g1=modeling(nsim=10000, n=100, mu=mu_gen[,1], sigma=0.65)
n100g1
n100g2=modeling(nsim=10000, n=100, mu=mu_gen[,2], sigma=0.65)
n100g2
n100g3=modeling(nsim=10000, n=100, mu=mu_gen[,3], sigma=0.65)
n100g3
n100g4=modeling(nsim=10000, n=100, mu=mu_gen[,4], sigma=0.65)
n100g4
n100g5=modeling(nsim=10000, n=100, mu=mu_gen[,5], sigma=0.65)
n100g5
n100g6=modeling(nsim=10000, n=100, mu=mu_gen[,6], sigma=0.65)
n100g6
end_time <- Sys.time()
# Running time 6.4 hours
end_time - start_time

results_mod_sel5=as.matrix(rbind(n100g1,n100g2,n100g3,n100g4,n100g5,n100g6))
rownames(results_mod_sel5)=c('n100Emax','n100L-L','n100Lin','n100E','n100Q','n100Log')
saveRDS(results_mod_sel5, file="results_mod_sel5.Rds")

###############################CODE 6 ######################################################
start_time <- Sys.time()

n150g1=modeling(nsim=10000, n=150, mu=mu_gen[,1], sigma=0.65)
n150g1
n150g2=modeling(nsim=10000, n=150, mu=mu_gen[,2], sigma=0.65)
n150g2
n150g3=modeling(nsim=10000, n=150, mu=mu_gen[,3], sigma=0.65)
n150g3
n150g4=modeling(nsim=10000, n=150, mu=mu_gen[,4], sigma=0.65)
n150g4
n150g5=modeling(nsim=10000, n=150, mu=mu_gen[,5], sigma=0.65)
n150g5
n150g6=modeling(nsim=10000, n=150, mu=mu_gen[,6], sigma=0.65)
n150g6
end_time <- Sys.time()
# Running time 7.28 hours
end_time - start_time

results_mod_sel6=as.matrix(rbind(n150g1,n150g2,n150g3,n150g4,n150g5,n150g6))
rownames(results_mod_sel6)=c('n150Emax','n150L-L','n150Lin','n150E','n150Q','n150Log')
saveRDS(results_mod_sel6, file="results_mod_sel6.Rds")




########################################################################################
###                        Results in Table 3                                        ###   
########################################################################################

results_mod_sel1=readRDS("results_mod_sel1.Rds") 
results_mod_sel2=readRDS("results_mod_sel2.Rds") 
results_mod_sel3=readRDS("results_mod_sel3.Rds") 
results_mod_sel4=readRDS("results_mod_sel4.Rds") 
results_mod_sel5=readRDS("results_mod_sel5.Rds") 
results_mod_sel6=readRDS("results_mod_sel6.Rds") 

#n=10
MCPn10=results_mod_sel1[,1:7]/10000
Tn10=results_mod_sel1[,8:15]/10000
Fn10=results_mod_sel1[,16:23]/10000
Nn10=results_mod_sel1[,24:31]/10000

rbind(
c(MCPn10[1,1],MCPn10[2,2],MCPn10[3,3],MCPn10[4,4],MCPn10[5,5],MCPn10[6,6]),
c(Tn10[1,1],Tn10[2,2],Tn10[3,3],Tn10[4,4],Tn10[5,5],Tn10[6,6]),
c(Fn10[1,1],Fn10[2,2],Fn10[3,3],Fn10[4,4],Fn10[5,5],Fn10[6,6]),
c(Nn10[1,1],Nn10[2,2],Nn10[3,3],Nn10[4,4],Nn10[5,5],Nn10[6,6]))

#n=25
MCPn25=results_mod_sel2[,1:7]/10000
Tn25=results_mod_sel2[,8:15]/10000
Fn25=results_mod_sel2[,16:23]/10000
Nn25=results_mod_sel2[,24:31]/10000

rbind(
   c(MCPn25[1,1],MCPn25[2,2],MCPn25[3,3],MCPn25[4,4],MCPn25[5,5],MCPn25[6,6]),
   c(Tn25[1,1],Tn25[2,2],Tn25[3,3],Tn25[4,4],Tn25[5,5],Tn25[6,6]),
   c(Fn25[1,1],Fn25[2,2],Fn25[3,3],Fn25[4,4],Fn25[5,5],Fn25[6,6]),
   c(Nn25[1,1],Nn25[2,2],Nn25[3,3],Nn25[4,4],Nn25[5,5],Nn25[6,6]))

#n=50
MCPn50=results_mod_sel3[,1:7]/10000
Tn50=results_mod_sel3[,8:15]/10000
Fn50=results_mod_sel3[,16:23]/10000
Nn50=results_mod_sel3[,24:31]/10000

rbind(
   c(MCPn50[1,1],MCPn50[2,2],MCPn50[3,3],MCPn50[4,4],MCPn50[5,5],MCPn50[6,6]),
   c(Tn50[1,1],Tn50[2,2],Tn50[3,3],Tn50[4,4],Tn50[5,5],Tn50[6,6]),
   c(Fn50[1,1],Fn50[2,2],Fn50[3,3],Fn50[4,4],Fn50[5,5],Fn50[6,6]),
   c(Nn50[1,1],Nn50[2,2],Nn50[3,3],Nn50[4,4],Nn50[5,5],Nn50[6,6]))

#n=75
MCPn75=results_mod_sel4[,1:7]/10000
Tn75=results_mod_sel4[,8:15]/10000
Fn75=results_mod_sel4[,16:23]/10000
Nn75=results_mod_sel4[,24:31]/10000

rbind(
   c(MCPn75[1,1],MCPn75[2,2],MCPn75[3,3],MCPn75[4,4],MCPn75[5,5],MCPn75[6,6]),
   c(Tn75[1,1],Tn75[2,2],Tn75[3,3],Tn75[4,4],Tn75[5,5],Tn75[6,6]),
   c(Fn75[1,1],Fn75[2,2],Fn75[3,3],Fn75[4,4],Fn75[5,5],Fn75[6,6]),
   c(Nn75[1,1],Nn75[2,2],Nn75[3,3],Nn75[4,4],Nn75[5,5],Nn75[6,6]))

#n=100
MCPn100=results_mod_sel5[,1:7]/10000
Tn100=results_mod_sel5[,8:15]/10000
Fn100=results_mod_sel5[,16:23]/10000
Nn100=results_mod_sel5[,24:31]/10000

rbind(
   c(MCPn100[1,1],MCPn100[2,2],MCPn100[3,3],MCPn100[4,4],MCPn100[5,5],MCPn100[6,6]),
   c(Tn100[1,1],Tn100[2,2],Tn100[3,3],Tn100[4,4],Tn100[5,5],Tn100[6,6]),
   c(Fn100[1,1],Fn100[2,2],Fn100[3,3],Fn100[4,4],Fn100[5,5],Fn100[6,6]),
   c(Nn100[1,1],Nn100[2,2],Nn100[3,3],Nn100[4,4],Nn100[5,5],Nn100[6,6]))

#n=150
MCPn150=results_mod_sel6[,1:7]/10000
Tn150=results_mod_sel6[,8:15]/10000
Fn150=results_mod_sel6[,16:23]/10000
Nn150=results_mod_sel6[,24:31]/10000

rbind(
   c(MCPn150[1,1],MCPn150[2,2],MCPn150[3,3],MCPn150[4,4],MCPn150[5,5],MCPn150[6,6]),
   c(Tn150[1,1],Tn150[2,2],Tn150[3,3],Tn150[4,4],Tn150[5,5],Tn150[6,6]),
   c(Fn150[1,1],Fn150[2,2],Fn150[3,3],Fn150[4,4],Fn150[5,5],Fn150[6,6]),
   c(Nn150[1,1],Nn150[2,2],Nn150[3,3],Nn150[4,4],Nn150[5,5],Nn150[6,6]))