#############################################################################################################
### R code for Simulation Studies----Section 5.1.1 Power Comparison of the GMCTs with MCP-Mod
### MA and MCDERMOTT Generalized Multiple Contrast Tests in Dose-Response Studies
### Figure 1,2,3
### R program written by Shiyang Ma at 2018-12-05
#############################################################################################################

### Simulation studies were conducted using R studio version: 3.5.0 under Nemo, a Red Hat Linux server in the
### Department of Biostatistics and Computational Biology at University of Rochester Medical Center. 
### Random numbers were generated using R package 'mvtnorm' version 1.0-8.
### Please note that different versions of R studio might generate slightly different simulation results since the
### R package 'mvtnorm' might have different version and thus have different random number generators even for the
### same seed. But the difference should be negligible (within simulation error). 

#################Using the same simulation setting as Bretz et al 2005 simulation studies ##################
library("mvtnorm")
#5 dosage groups
d=c(0,0.05, 0.2, 0.6, 1)

#13 data generating shapes in Table 2 as well as constant (in order to calculate the FWER)
#Constant
mu0=rep(0.2,5)
#Emax
mu1=0.2+0.7*d/(0.2+d)
#Linear in log-dose
mu2=0.2+0.6*log(5*d+1)/log(6)
#Linear
mu3=0.2+0.6*d
#Exponential 1
mu4=0.183+0.017*exp(2*d*log(6))
#Exponential 2
mu5=0.19924+0.00076*exp(d/0.15)
#Quadratic 1
mu6=0.2+2.049*d-1.749*d^2
#Quadratic 2
mu7=0.2+2.4*(d-d^2)
#Logistic
mu8=0.193+0.607/(1+exp(10*log(3)*(0.4-d)))
#Double-logistic
mu9=(0.198+0.61/(1+exp(18*(0.3-d))))*ifelse(d<=0.5,1,0)+(0.499+0.309/(1+exp(18*(d-0.7))))*ifelse(d>0.5,1,0)
#Step 1
mu10=0.2+0.6*ifelse(d>=1,1,0)
#Step 2
mu11=0.2+0.6*ifelse(d>=0.6,1,0)
#Step 3
mu12=0.2+0.6*ifelse(d>=0.2,1,0)   
#Step 4
mu13=0.2+0.6*ifelse(d>=0.05,1,0)   

###Figure 1: Two differnt sets of candidate dose-response models
dd=seq(0,1,by=0.001)

postscript("MA_AND_MCDERMOTT_Figure1.eps", onefile=F, paper="special", height=8, width=15, horizontal=F)

par(mfrow=c(1,2))
#Candidate set of models from Bretz et al. 2005 (narrower)
plot(dd,0.2+0.7*dd/(0.2+dd),type='l',
     xlab='Dosage',ylab='Response',ylim=c(0,1),col='green',lwd=2,lty=1,
     main=expression(bold(paste("Candidate set of models from Bretz et al"^"7"
                           ~'(narrower)'))) )
points(d,mu1)
lines(dd,0.2+0.6*log(5*dd+1)/log(6),col='red',lwd=2,lty=2)
points(d,mu2)
lines(dd,0.2+0.6*dd,col='blue',lwd=2,lty=3)
points(d,mu3)
lines(dd,0.183+0.017*exp(2*dd*log(6)),col='pink',lwd=2,lty=4)
points(d,mu4)
lines(dd,0.2+2.049*dd-1.749*dd^2,col='yellow',lwd=2,lty=5)
points(d,mu6)
lines(dd,0.193+0.607/(1+exp(10*log(3)*(0.4-dd))),col='black',lwd=2,lty=6)
points(d,mu8)
legend("bottomright", c("Emax", "Linear in log (dose)", "Linear",
                        "Exponential 1", "Quadratic 1", "Logistic"),
       lwd=rep(2,6),cex=0.6,bty = "n",lty=1:6,
       col=c('green','red','blue','pink','yellow','black')) 

#Another candidate set (wider)
plot(dd,0.2+0.7*dd/(0.2+dd),type='l',
     xlab='Dosage',ylab='Response',ylim=c(0,1),col='green',lwd=2,lty=1,
     main='Another candidate set of models (wider)')
points(d,mu1)
lines(dd,0.2+0.6*log(5*dd+1)/log(6),col='red',lwd=2,lty=2)
points(d,mu2)
lines(dd,0.2+0.6*ifelse(dd>=0.05,1,0),col='blue',lwd=2,lty=3)
points(d,mu13)
lines(dd,0.19924+0.00076*exp(dd/0.15),col='pink',lwd=2,lty=4)
points(d,mu5)
lines(dd,0.2+2.4*(dd-dd^2),col='yellow',lwd=2,lty=5)
points(d,mu7)
lines(dd,(0.198+0.61/(1+exp(18*(0.3-dd))))*ifelse(dd<=0.5,1,0)+(0.499+0.309/(1+exp(18*(dd-0.7))))*ifelse(dd>0.5,1,0),lwd=2,lty=6)
points(d,mu9)
legend('bottomright', c("Emax", "Linear in log (dose)", 'Step 4',
                   "Exponetial 2", "Quadratic 2", 'Double-logistic'),lty=1:6,
       lwd=rep(2,6),bty = "n",
       cex=0.6,col=c('green','red','blue','pink','yellow','black')) 
dev.off()

#########################################################################
###Simulation studies----Proof of Concept Testing
#########################################################################

#Different data generating shape
mu_gen=cbind(mu1,mu2,mu3,mu4,mu5,mu6,mu7,mu8,mu9,mu10,mu11,mu12,mu13,mu0)

#Calculate contrasts
contrast=function(mu){
   (mu-mean(mu))/norm(mu-mean(mu),type='2')
}

#Contrasts of 6 candidate models from Bretz et al. 2005 (narrower)
c1_N=contrast(mu1) #Emax
c2_N=contrast(mu2) #L-L 
c3_N=contrast(mu3) #Linear
c4_N=contrast(mu4) #E1
c5_N=contrast(mu6) #Q1
c6_N=contrast(mu8)  #Logistic

rho12_N=sum(c1_N*c2_N)/sqrt(sum(c1_N^2)*sum(c2_N^2))
rho13_N=sum(c1_N*c3_N)/sqrt(sum(c1_N^2)*sum(c3_N^2))
rho14_N=sum(c1_N*c4_N)/sqrt(sum(c1_N^2)*sum(c4_N^2))
rho15_N=sum(c1_N*c5_N)/sqrt(sum(c1_N^2)*sum(c5_N^2))
rho16_N=sum(c1_N*c6_N)/sqrt(sum(c1_N^2)*sum(c6_N^2))

rho23_N=sum(c2_N*c3_N)/sqrt(sum(c2_N^2)*sum(c3_N^2))
rho24_N=sum(c2_N*c4_N)/sqrt(sum(c2_N^2)*sum(c4_N^2))
rho25_N=sum(c2_N*c5_N)/sqrt(sum(c2_N^2)*sum(c5_N^2))
rho26_N=sum(c2_N*c6_N)/sqrt(sum(c2_N^2)*sum(c6_N^2))

rho34_N=sum(c3_N*c4_N)/sqrt(sum(c3_N^2)*sum(c4_N^2))
rho35_N=sum(c3_N*c5_N)/sqrt(sum(c3_N^2)*sum(c5_N^2))
rho36_N=sum(c3_N*c6_N)/sqrt(sum(c3_N^2)*sum(c6_N^2))

rho45_N=sum(c4_N*c5_N)/sqrt(sum(c4_N^2)*sum(c5_N^2))
rho46_N=sum(c4_N*c6_N)/sqrt(sum(c4_N^2)*sum(c6_N^2))
rho56_N=sum(c5_N*c6_N)/sqrt(sum(c5_N^2)*sum(c6_N^2))

Sigma_N=matrix(c(1,rho12_N, rho13_N,rho14_N,rho15_N, rho16_N,
                 rho12_N, 1, rho23_N, rho24_N,rho25_N,  rho26_N,
                 rho13_N, rho23_N, 1, rho34_N, rho35_N,  rho36_N,
                 rho14_N, rho24_N, rho34_N, 1, rho45_N,  rho46_N,
                 rho15_N, rho25_N, rho35_N, rho45_N, 1,  rho56_N,
                 rho16_N, rho26_N, rho36_N, rho46_N,  rho56_N, 1
),nrow=6,ncol=6)

#Contrasts of 6 candidate models from another candidate set (wider)
c1_W=contrast(mu1) #Emax
c2_W=contrast(mu2) #L-L 
c3_W=contrast(mu13) #Step 4
c4_W=contrast(mu5)  #E2
c5_W=contrast(mu7)  #Q2
c6_W=contrast(mu9) #Double-logistic

rho12_W=sum(c1_W*c2_W)/sqrt(sum(c1_W^2)*sum(c2_W^2))
rho13_W=sum(c1_W*c3_W)/sqrt(sum(c1_W^2)*sum(c3_W^2))
rho14_W=sum(c1_W*c4_W)/sqrt(sum(c1_W^2)*sum(c4_W^2))
rho15_W=sum(c1_W*c5_W)/sqrt(sum(c1_W^2)*sum(c5_W^2))
rho16_W=sum(c1_W*c6_W)/sqrt(sum(c1_W^2)*sum(c6_W^2))

rho23_W=sum(c2_W*c3_W)/sqrt(sum(c2_W^2)*sum(c3_W^2))
rho24_W=sum(c2_W*c4_W)/sqrt(sum(c2_W^2)*sum(c4_W^2))
rho25_W=sum(c2_W*c5_W)/sqrt(sum(c2_W^2)*sum(c5_W^2))
rho26_W=sum(c2_W*c6_W)/sqrt(sum(c2_W^2)*sum(c6_W^2))

rho34_W=sum(c3_W*c4_W)/sqrt(sum(c3_W^2)*sum(c4_W^2))
rho35_W=sum(c3_W*c5_W)/sqrt(sum(c3_W^2)*sum(c5_W^2))
rho36_W=sum(c3_W*c6_W)/sqrt(sum(c3_W^2)*sum(c6_W^2))

rho45_W=sum(c4_W*c5_W)/sqrt(sum(c4_W^2)*sum(c5_W^2))
rho46_W=sum(c4_W*c6_W)/sqrt(sum(c4_W^2)*sum(c6_W^2))
rho56_W=sum(c5_W*c6_W)/sqrt(sum(c5_W^2)*sum(c6_W^2))

Sigma_W=matrix(c(1,rho12_W, rho13_W,rho14_W,rho15_W, rho16_W,
               rho12_W, 1, rho23_W, rho24_W,rho25_W,  rho26_W,
               rho13_W, rho23_W, 1, rho34_W, rho35_W,  rho36_W,
               rho14_W, rho24_W, rho34_W, 1, rho45_W,  rho46_W,
               rho15_W, rho25_W, rho35_W, rho45_W, 1,  rho56_W,
               rho16_W, rho26_W, rho36_W, rho46_W,  rho56_W, 1
),nrow=6,ncol=6)


#################step contrasts#########################
step1_con=contrast(mu10)
step2_con=contrast(mu11)
step3_con=contrast(mu12)
step4_con=contrast(mu13)

rho12_step=sum(step1_con*step2_con)/sqrt(sum(step1_con^2)*sum(step2_con^2))
rho13_step=sum(step1_con*step3_con)/sqrt(sum(step1_con^2)*sum(step3_con^2))
rho14_step=sum(step1_con*step4_con)/sqrt(sum(step1_con^2)*sum(step4_con^2))
rho23_step=sum(step2_con*step3_con)/sqrt(sum(step2_con^2)*sum(step3_con^2))
rho24_step=sum(step2_con*step4_con)/sqrt(sum(step2_con^2)*sum(step4_con^2))
rho34_step=sum(step3_con*step4_con)/sqrt(sum(step3_con^2)*sum(step4_con^2))

Sigma_step=matrix(c(1,rho12_step, rho13_step,rho14_step,
                    rho12_step, 1, rho23_step, rho24_step,
                    rho13_step, rho23_step, 1, rho34_step, 
                    rho14_step, rho24_step, rho34_step, 1
),nrow=4,ncol=4)


#Write a PoC function for the narrower candidate set of models 
PoC_N=function(nsim=10000,n=10, mu=mu_gen[,1],sigma=1.478){
   
   #Set up a fixed simulation seeds
   set.seed(12345)  
   #Degrees of freedom
   ddf=n*5-5  
   #Proof of Concept p-value
   pvalue_MCPMod=rep(NA,nsim)
   pvalue_F=rep(NA,nsim)
   pvalue_N=rep(NA,nsim)
   pvalue_LRT=rep(NA,nsim)
   pvalue_step=rep(NA,nsim)
   
   for (s in 1:nsim){
      #Generate data with 5 dosage group, sigma=1.478
      Y=rmvnorm(n,mean=mu,sigma = diag(sigma^2,nrow=5,ncol=5))
      #Response
      resp=c(Y[,1], Y[,2],Y[,3], Y[,4],Y[,5])
      dose=c(rep(0,n),rep(0.05,n),rep(0.2,n),rep(0.6,n),rep(1,n))
      
      #Multiple contrast test
      ybar1=mean(resp[dose==0])
      ybar2=mean(resp[dose==0.05])
      ybar3=mean(resp[dose==0.2])
      ybar4=mean(resp[dose==0.6])
      ybar5=mean(resp[dose==1])
      ybar=c(ybar1,ybar2,ybar3,ybar4,ybar5)
      
      #Contrast estimate of 6 models
      ce1=sum(c1_N*ybar)
      ce2=sum(c2_N*ybar)  
      ce3=sum(c3_N*ybar)
      ce4=sum(c4_N*ybar)
      ce5=sum(c5_N*ybar)
      ce6=sum(c6_N*ybar)
      ce=c(ce1,ce2,ce3,ce4,ce5,ce6)
      
      #T-value
      S2=(sum((resp[dose==0]-ybar1)^2)+sum((resp[dose==0.05]-ybar2)^2)+
             sum((resp[dose==0.2]-ybar3)^2)+sum((resp[dose==0.6]-ybar4)^2)+
             sum((resp[dose==1]-ybar5)^2))/ddf
      t1=ce1/sqrt(S2*sum(c1_N^2)/n)
      t2=ce2/sqrt(S2*sum(c2_N^2)/n)
      t3=ce3/sqrt(S2*sum(c3_N^2)/n)
      t4=ce4/sqrt(S2*sum(c4_N^2)/n)
      t5=ce5/sqrt(S2*sum(c5_N^2)/n)
      t6=ce6/sqrt(S2*sum(c6_N^2)/n)
      t=c(t1,t2,t3,t4,t5,t6)
      
      #Dependent p values
      p1=1-pt(t1,df=ddf)
      p2=1-pt(t2,df=ddf)
      p3=1-pt(t3,df=ddf)
      p4=1-pt(t4,df=ddf)
      p5=1-pt(t5,df=ddf)
      p6=1-pt(t6,df=ddf)
      
      #PoC p-value of MCP-Mod
      pvalue_MCPMod[s]=1-pmvt(lower=rep(-Inf,6),upper =rep(max(t),6), corr=Sigma_N, df=ddf)[1]
      
###############################Fisher's Combination test#####################################
      cov12_F=3.279*rho12_N+0.711*rho12_N^2+0.727/ddf+0.129*rho12_N/ddf-0.768*rho12_N^2/ddf
      cov13_F=3.279*rho13_N+0.711*rho13_N^2+0.727/ddf+0.129*rho13_N/ddf-0.768*rho13_N^2/ddf
      cov14_F=3.279*rho14_N+0.711*rho14_N^2+0.727/ddf+0.129*rho14_N/ddf-0.768*rho14_N^2/ddf
      cov15_F=3.279*rho15_N+0.711*rho15_N^2+0.727/ddf+0.129*rho15_N/ddf-0.768*rho15_N^2/ddf
      cov16_F=3.279*rho16_N+0.711*rho16_N^2+0.727/ddf+0.129*rho16_N/ddf-0.768*rho16_N^2/ddf
      
      cov23_F=3.279*rho23_N+0.711*rho23_N^2+0.727/ddf+0.129*rho23_N/ddf-0.768*rho23_N^2/ddf
      cov24_F=3.279*rho24_N+0.711*rho24_N^2+0.727/ddf+0.129*rho24_N/ddf-0.768*rho24_N^2/ddf
      cov25_F=3.279*rho25_N+0.711*rho25_N^2+0.727/ddf+0.129*rho25_N/ddf-0.768*rho25_N^2/ddf
      cov26_F=3.279*rho26_N+0.711*rho26_N^2+0.727/ddf+0.129*rho26_N/ddf-0.768*rho26_N^2/ddf
      
      cov34_F=3.279*rho34_N+0.711*rho34_N^2+0.727/ddf+0.129*rho34_N/ddf-0.768*rho34_N^2/ddf
      cov35_F=3.279*rho35_N+0.711*rho35_N^2+0.727/ddf+0.129*rho35_N/ddf-0.768*rho35_N^2/ddf
      cov36_F=3.279*rho36_N+0.711*rho36_N^2+0.727/ddf+0.129*rho36_N/ddf-0.768*rho36_N^2/ddf
      
      cov45_F=3.279*rho45_N+0.711*rho45_N^2+0.727/ddf+0.129*rho45_N/ddf-0.768*rho45_N^2/ddf
      cov46_F=3.279*rho46_N+0.711*rho46_N^2+0.727/ddf+0.129*rho46_N/ddf-0.768*rho46_N^2/ddf
      cov56_F=3.279*rho56_N+0.711*rho56_N^2+0.727/ddf+0.129*rho56_N/ddf-0.768*rho56_N^2/ddf
      #The mean and variance of the Fisher's statistic 
      E=2*6
      var=4*6+2*(cov12_F+cov13_F+cov14_F+cov15_F+cov16_F+
                    cov23_F+cov24_F+cov25_F+cov26_F+
                    cov34_F+cov35_F+cov36_F+
                    cov45_F+cov46_F+
                    cov56_F)
      #Degrees of freedom f  
      f=2*E^2/var
      c=var/(2*E)
      
      phiFobs=-2*(log(p1)+log(p2)+log(p3)+log(p4)+log(p5)+log(p6))
      pvalue_F[s] = 1-pchisq(phiFobs/c,df=f)

###############################Inverse Normal Combination method############################
      cov12_N=rho12_N+0.00019*rho12_N^3-0.02378*rho12_N/ddf+0.01891*rho12_N^3/ddf
      cov13_N=rho13_N+0.00019*rho13_N^3-0.02378*rho13_N/ddf+0.01891*rho13_N^3/ddf
      cov14_N=rho14_N+0.00019*rho14_N^3-0.02378*rho14_N/ddf+0.01891*rho14_N^3/ddf
      cov15_N=rho15_N+0.00019*rho15_N^3-0.02378*rho15_N/ddf+0.01891*rho15_N^3/ddf
      cov16_N=rho16_N+0.00019*rho16_N^3-0.02378*rho16_N/ddf+0.01891*rho16_N^3/ddf
     
      cov23_N=rho23_N+0.00019*rho23_N^3-0.02378*rho23_N/ddf+0.01891*rho23_N^3/ddf
      cov24_N=rho24_N+0.00019*rho24_N^3-0.02378*rho24_N/ddf+0.01891*rho24_N^3/ddf
      cov25_N=rho25_N+0.00019*rho25_N^3-0.02378*rho25_N/ddf+0.01891*rho25_N^3/ddf
      cov26_N=rho26_N+0.00019*rho26_N^3-0.02378*rho26_N/ddf+0.01891*rho26_N^3/ddf
       
      cov34_N=rho34_N+0.00019*rho34_N^3-0.02378*rho34_N/ddf+0.01891*rho34_N^3/ddf
      cov35_N=rho35_N+0.00019*rho35_N^3-0.02378*rho35_N/ddf+0.01891*rho35_N^3/ddf
      cov36_N=rho36_N+0.00019*rho36_N^3-0.02378*rho36_N/ddf+0.01891*rho36_N^3/ddf
       
      cov45_N=rho45_N+0.00019*rho45_N^3-0.02378*rho45_N/ddf+0.01891*rho45_N^3/ddf
      cov46_N=rho46_N+0.00019*rho46_N^3-0.02378*rho46_N/ddf+0.01891*rho46_N^3/ddf
      cov56_N=rho56_N+0.00019*rho56_N^3-0.02378*rho56_N/ddf+0.01891*rho56_N^3/ddf
   
      pvalue_N[s] =1-pnorm(1/sqrt(6)*(qnorm(1-p1)+qnorm(1-p2)+qnorm(1-p3)+
                     qnorm(1-p4)+qnorm(1-p5)+qnorm(1-p6)),mean=0,
                     sd=sqrt(1+2/6*(cov12_N+cov13_N+cov14_N+cov15_N+cov16_N+
                                       cov23_N+cov24_N+cov25_N+cov26_N+
                                       cov34_N+cov35_N+cov36_N+
                                       cov45_N+cov46_N+
                                       cov56_N) ))

##########################LRT (Bartholomew test with simple order)###########################
      mon_reg  = ybar
      mean(mon_reg)
      monotone = FALSE
      while (monotone==FALSE)
      {
         monotone = TRUE
         for (j in 2:5)
         {
            if (mon_reg[j]<mon_reg[j-1]-(1e-10)) 
            {
               meanest      = (mon_reg[j]+mon_reg[j-1])/2
               mon_reg[j-1] = meanest
               mon_reg[j]   = meanest
               monotone     = FALSE
            }
         }
      }
      mon_reg 
      mean(mon_reg)
      
      bartholomew = function(isodmean,n=n)
      {
         #Level probabilities for simple order
         plk = c(1/5,5/12,7/24,1/12,1/120)  
         overallm = mean(isodmean)
         test_E2  = (n/sigma^2)*sum((isodmean-overallm)^2)
         prob=0
         if (test_E2==0) prob=plk[1]
         {
            for ( l in 2:5 )
            {
               prob = prob + plk[l] * (1-pchisq(df=l-1,ncp=0,q=test_E2))
            }
         }
         prob
      }
      pvalue_LRT[s]=bartholomew(mon_reg,n=n)
      
################################Step Contrasts test#####################################
#contrast estimate of 4 step models
ce1_step=sum(step1_con*ybar)
ce2_step=sum(step2_con*ybar)  
ce3_step=sum(step3_con*ybar)
ce4_step=sum(step4_con*ybar)
#T-values
t1_step=ce1_step/sqrt(S2*sum(step1_con^2)/n)
t2_step=ce2_step/sqrt(S2*sum(step2_con^2)/n)
t3_step=ce3_step/sqrt(S2*sum(step3_con^2)/n)
t4_step=ce4_step/sqrt(S2*sum(step4_con^2)/n)
t_step=c(t1_step,t2_step,t3_step,t4_step)
pvalue_step[s]=1-pmvt(lower=rep(-Inf,4),upper =rep(max(t_step),4),corr=Sigma_step, df=ddf)[1]
   }
   #PoC probability
   PoC_prob=c(sum(pvalue_MCPMod<0.05)/nsim,
              sum(pvalue_F<0.05)/nsim,
              sum(pvalue_N<0.05)/nsim,
              sum(pvalue_LRT<0.05)/nsim,
              sum(pvalue_step<0.05)/nsim)
return(PoC_prob)
   
}

#Write a PoC function for the wider candidate set of models 
PoC_W=function(nsim=10000,n=10, mu=mu_gen[,1],sigma=1.478){
   
   #Set up a fixed simulation seeds
   set.seed(12345)  
   #Degrees of freedom
   ddf=n*5-5  
   #Proof of Concept p-value
   pvalue_MCPMod=rep(NA,nsim)
   pvalue_F=rep(NA,nsim)
   pvalue_N=rep(NA,nsim)
   pvalue_LRT=rep(NA,nsim)
   pvalue_step=rep(NA,nsim)
   
   for (s in 1:nsim){
      #Generate data with 5 dosage group, sigma=1.478
      Y=rmvnorm(n,mean=mu,sigma = diag(sigma^2,nrow=5,ncol=5))
      #Response
      resp=c(Y[,1], Y[,2],Y[,3], Y[,4],Y[,5])
      dose=c(rep(0,n),rep(0.05,n),rep(0.2,n),rep(0.6,n),rep(1,n))
      
      #Multiple contrast test
      ybar1=mean(resp[dose==0])
      ybar2=mean(resp[dose==0.05])
      ybar3=mean(resp[dose==0.2])
      ybar4=mean(resp[dose==0.6])
      ybar5=mean(resp[dose==1])
      ybar=c(ybar1,ybar2,ybar3,ybar4,ybar5)
      
      #Contrast estimate of 6 models
      ce1=sum(c1_W*ybar)
      ce2=sum(c2_W*ybar)  
      ce3=sum(c3_W*ybar)
      ce4=sum(c4_W*ybar)
      ce5=sum(c5_W*ybar)
      ce6=sum(c6_W*ybar)
      ce=c(ce1,ce2,ce3,ce4,ce5,ce6)
      
      #T-value
      S2=(sum((resp[dose==0]-ybar1)^2)+sum((resp[dose==0.05]-ybar2)^2)+
             sum((resp[dose==0.2]-ybar3)^2)+sum((resp[dose==0.6]-ybar4)^2)+
             sum((resp[dose==1]-ybar5)^2))/ddf
      t1=ce1/sqrt(S2*sum(c1_W^2)/n)
      t2=ce2/sqrt(S2*sum(c2_W^2)/n)
      t3=ce3/sqrt(S2*sum(c3_W^2)/n)
      t4=ce4/sqrt(S2*sum(c4_W^2)/n)
      t5=ce5/sqrt(S2*sum(c5_W^2)/n)
      t6=ce6/sqrt(S2*sum(c6_W^2)/n)
      t=c(t1,t2,t3,t4,t5,t6)
      
      #Dependent p values
      p1=1-pt(t1,df=ddf)
      p2=1-pt(t2,df=ddf)
      p3=1-pt(t3,df=ddf)
      p4=1-pt(t4,df=ddf)
      p5=1-pt(t5,df=ddf)
      p6=1-pt(t6,df=ddf)
      
      #PoC p-value of MCP-Mod
      pvalue_MCPMod[s]=1-pmvt(lower=rep(-Inf,6),upper =rep(max(t),6), corr=Sigma_W, df=ddf)[1]
      
      ###############################Fisher's Combination test#####################################
      cov12_F=3.279*rho12_W+0.711*rho12_W^2+0.727/ddf+0.129*rho12_W/ddf-0.768*rho12_W^2/ddf
      cov13_F=3.279*rho13_W+0.711*rho13_W^2+0.727/ddf+0.129*rho13_W/ddf-0.768*rho13_W^2/ddf
      cov14_F=3.279*rho14_W+0.711*rho14_W^2+0.727/ddf+0.129*rho14_W/ddf-0.768*rho14_W^2/ddf
      cov15_F=3.279*rho15_W+0.711*rho15_W^2+0.727/ddf+0.129*rho15_W/ddf-0.768*rho15_W^2/ddf
      cov16_F=3.279*rho16_W+0.711*rho16_W^2+0.727/ddf+0.129*rho16_W/ddf-0.768*rho16_W^2/ddf
      
      cov23_F=3.279*rho23_W+0.711*rho23_W^2+0.727/ddf+0.129*rho23_W/ddf-0.768*rho23_W^2/ddf
      cov24_F=3.279*rho24_W+0.711*rho24_W^2+0.727/ddf+0.129*rho24_W/ddf-0.768*rho24_W^2/ddf
      cov25_F=3.279*rho25_W+0.711*rho25_W^2+0.727/ddf+0.129*rho25_W/ddf-0.768*rho25_W^2/ddf
      cov26_F=3.279*rho26_W+0.711*rho26_W^2+0.727/ddf+0.129*rho26_W/ddf-0.768*rho26_W^2/ddf
      
      cov34_F=3.279*rho34_W+0.711*rho34_W^2+0.727/ddf+0.129*rho34_W/ddf-0.768*rho34_W^2/ddf
      cov35_F=3.279*rho35_W+0.711*rho35_W^2+0.727/ddf+0.129*rho35_W/ddf-0.768*rho35_W^2/ddf
      cov36_F=3.279*rho36_W+0.711*rho36_W^2+0.727/ddf+0.129*rho36_W/ddf-0.768*rho36_W^2/ddf
      
      cov45_F=3.279*rho45_W+0.711*rho45_W^2+0.727/ddf+0.129*rho45_W/ddf-0.768*rho45_W^2/ddf
      cov46_F=3.279*rho46_W+0.711*rho46_W^2+0.727/ddf+0.129*rho46_W/ddf-0.768*rho46_W^2/ddf
      cov56_F=3.279*rho56_W+0.711*rho56_W^2+0.727/ddf+0.129*rho56_W/ddf-0.768*rho56_W^2/ddf
      #The mean and variance of the Fisher's statistic 
      E=2*6
      var=4*6+2*(cov12_F+cov13_F+cov14_F+cov15_F+cov16_F+
                    cov23_F+cov24_F+cov25_F+cov26_F+
                    cov34_F+cov35_F+cov36_F+
                    cov45_F+cov46_F+
                    cov56_F)
      #Degrees of freedom f  
      f=2*E^2/var
      c=var/(2*E)
      
      phiFobs=-2*(log(p1)+log(p2)+log(p3)+log(p4)+log(p5)+log(p6))
      pvalue_F[s] = 1-pchisq(phiFobs/c,df=f)
      
      ###############################Inverse Normal Combination method############################
      cov12_N=rho12_W+0.00019*rho12_W^3-0.02378*rho12_W/ddf+0.01891*rho12_W^3/ddf
      cov13_N=rho13_W+0.00019*rho13_W^3-0.02378*rho13_W/ddf+0.01891*rho13_W^3/ddf
      cov14_N=rho14_W+0.00019*rho14_W^3-0.02378*rho14_W/ddf+0.01891*rho14_W^3/ddf
      cov15_N=rho15_W+0.00019*rho15_W^3-0.02378*rho15_W/ddf+0.01891*rho15_W^3/ddf
      cov16_N=rho16_W+0.00019*rho16_W^3-0.02378*rho16_W/ddf+0.01891*rho16_W^3/ddf
      
      cov23_N=rho23_W+0.00019*rho23_W^3-0.02378*rho23_W/ddf+0.01891*rho23_W^3/ddf
      cov24_N=rho24_W+0.00019*rho24_W^3-0.02378*rho24_W/ddf+0.01891*rho24_W^3/ddf
      cov25_N=rho25_W+0.00019*rho25_W^3-0.02378*rho25_W/ddf+0.01891*rho25_W^3/ddf
      cov26_N=rho26_W+0.00019*rho26_W^3-0.02378*rho26_W/ddf+0.01891*rho26_W^3/ddf

      cov34_N=rho34_W+0.00019*rho34_W^3-0.02378*rho34_W/ddf+0.01891*rho34_W^3/ddf
      cov35_N=rho35_W+0.00019*rho35_W^3-0.02378*rho35_W/ddf+0.01891*rho35_W^3/ddf
      cov36_N=rho36_W+0.00019*rho36_W^3-0.02378*rho36_W/ddf+0.01891*rho36_W^3/ddf
      
      cov45_N=rho45_W+0.00019*rho45_W^3-0.02378*rho45_W/ddf+0.01891*rho45_W^3/ddf
      cov46_N=rho46_W+0.00019*rho46_W^3-0.02378*rho46_W/ddf+0.01891*rho46_W^3/ddf
      cov56_N=rho56_W+0.00019*rho56_W^3-0.02378*rho56_W/ddf+0.01891*rho56_W^3/ddf
      
      pvalue_N[s] =1-pnorm(1/sqrt(6)*(qnorm(1-p1)+qnorm(1-p2)+qnorm(1-p3)+
                                         qnorm(1-p4)+qnorm(1-p5)+qnorm(1-p6)),mean=0,
                           sd=sqrt(1+2/6*(cov12_N+cov13_N+cov14_N+cov15_N+cov16_N+
                                             cov23_N+cov24_N+cov25_N+cov26_N+
                                             cov34_N+cov35_N+cov36_N+
                                             cov45_N+cov46_N+
                                             cov56_N) ))
      
      ##########################LRT (Bartholomew test with simple order)###########################
      mon_reg  = ybar
      mean(mon_reg)
      monotone = FALSE
      while (monotone==FALSE)
      {
         monotone = TRUE
         for (j in 2:5)
         {
            if (mon_reg[j]<mon_reg[j-1]-(1e-10)) 
            {
               meanest      = (mon_reg[j]+mon_reg[j-1])/2
               mon_reg[j-1] = meanest
               mon_reg[j]   = meanest
               monotone     = FALSE
            }
         }
      }
      mon_reg 
      mean(mon_reg)
      
      bartholomew = function(isodmean,n=n)
      {
         #Level probabilities for simple order
         plk = c(1/5,5/12,7/24,1/12,1/120)  
         overallm = mean(ybar)
         test_E2  = (n/sigma^2)*sum((isodmean-overallm)^2)
         prob=0
         if (test_E2==0) prob=plk[1]
         {
            for ( l in 2:5 )
            {
               prob = prob + plk[l] * (1-pchisq(df=l-1,ncp=0,q=test_E2))
            }
         }
         prob
      }
      pvalue_LRT[s]=bartholomew(mon_reg,n=n)
      
      ###############################Step Contrasts test#####################################
      #contrast estimate of 4 step models
      ce1_step=sum(step1_con*ybar)
      ce2_step=sum(step2_con*ybar)  
      ce3_step=sum(step3_con*ybar)
      ce4_step=sum(step4_con*ybar)
      #T-values
      t1_step=ce1_step/sqrt(S2*sum(step1_con^2)/n)
      t2_step=ce2_step/sqrt(S2*sum(step2_con^2)/n)
      t3_step=ce3_step/sqrt(S2*sum(step3_con^2)/n)
      t4_step=ce4_step/sqrt(S2*sum(step4_con^2)/n)
      t_step=c(t1_step,t2_step,t3_step,t4_step)
      pvalue_step[s]=1-pmvt(lower=rep(-Inf,4),upper =rep(max(t_step),4),corr=Sigma_step, df=ddf)[1]
   }
   #PoC probability
   PoC_prob=c(sum(pvalue_MCPMod<0.05)/nsim,
              sum(pvalue_F<0.05)/nsim,
              sum(pvalue_N<0.05)/nsim,
              sum(pvalue_LRT<0.05)/nsim,
              sum(pvalue_step<0.05)/nsim)
   return(PoC_prob)
}

#########################################################################
### Conduct the simulation studies
#########################################################################

start_time <- Sys.time()
#Narrower candidate set of models
#Verify FWER
n10g0_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,14],sigma=1.478)
n25g0_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,14],sigma=1.478)
n50g0_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,14],sigma=1.478)
n75g0_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,14],sigma=1.478)
n100g0_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,14],sigma=1.478)
n150g0_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,14],sigma=1.478)

n10g1_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,1],sigma=1.478)
n25g1_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,1],sigma=1.478)
n50g1_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,1],sigma=1.478)
n75g1_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,1],sigma=1.478)
n100g1_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,1],sigma=1.478)
n150g1_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,1],sigma=1.478)

n10g2_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,2],sigma=1.478)
n25g2_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,2],sigma=1.478)
n50g2_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,2],sigma=1.478)
n75g2_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,2],sigma=1.478)
n100g2_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,2],sigma=1.478)
n150g2_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,2],sigma=1.478)

n10g3_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,3],sigma=1.478)
n25g3_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,3],sigma=1.478)
n50g3_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,3],sigma=1.478)
n75g3_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,3],sigma=1.478)
n100g3_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,3],sigma=1.478)
n150g3_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,3],sigma=1.478)

n10g4_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,4],sigma=1.478)
n25g4_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,4],sigma=1.478)
n50g4_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,4],sigma=1.478)
n75g4_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,4],sigma=1.478)
n100g4_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,4],sigma=1.478)
n150g4_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,4],sigma=1.478)

n10g5_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,5],sigma=1.478)
n25g5_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,5],sigma=1.478)
n50g5_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,5],sigma=1.478)
n75g5_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,5],sigma=1.478)
n100g5_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,5],sigma=1.478)
n150g5_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,5],sigma=1.478)

n10g6_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,6],sigma=1.478)
n25g6_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,6],sigma=1.478)
n50g6_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,6],sigma=1.478)
n75g6_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,6],sigma=1.478)
n100g6_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,6],sigma=1.478)
n150g6_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,6],sigma=1.478)

n10g7_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,7],sigma=1.478)
n25g7_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,7],sigma=1.478)
n50g7_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,7],sigma=1.478)
n75g7_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,7],sigma=1.478)
n100g7_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,7],sigma=1.478)
n150g7_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,7],sigma=1.478)

n10g8_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,8],sigma=1.478)
n25g8_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,8],sigma=1.478)
n50g8_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,8],sigma=1.478)
n75g8_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,8],sigma=1.478)
n100g8_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,8],sigma=1.478)
n150g8_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,8],sigma=1.478)

n10g9_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,9],sigma=1.478)
n25g9_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,9],sigma=1.478)
n50g9_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,9],sigma=1.478)
n75g9_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,9],sigma=1.478)
n100g9_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,9],sigma=1.478)
n150g9_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,9],sigma=1.478)

n10g10_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,10],sigma=1.478)
n25g10_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,10],sigma=1.478)
n50g10_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,10],sigma=1.478)
n75g10_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,10],sigma=1.478)
n100g10_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,10],sigma=1.478)
n150g10_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,10],sigma=1.478)

n10g11_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,11],sigma=1.478)
n25g11_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,11],sigma=1.478)
n50g11_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,11],sigma=1.478)
n75g11_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,11],sigma=1.478)
n100g11_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,11],sigma=1.478)
n150g11_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,11],sigma=1.478)

n10g12_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,12],sigma=1.478)
n25g12_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,12],sigma=1.478)
n50g12_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,12],sigma=1.478)
n75g12_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,12],sigma=1.478)
n100g12_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,12],sigma=1.478)
n150g12_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,12],sigma=1.478)

n10g13_N=PoC_N(nsim=10000,n=10,mu=mu_gen[,13],sigma=1.478)
n25g13_N=PoC_N(nsim=10000,n=25,mu=mu_gen[,13],sigma=1.478)
n50g13_N=PoC_N(nsim=10000,n=50,mu=mu_gen[,13],sigma=1.478)
n75g13_N=PoC_N(nsim=10000,n=75,mu=mu_gen[,13],sigma=1.478)
n100g13_N=PoC_N(nsim=10000,n=100,mu=mu_gen[,13],sigma=1.478)
n150g13_N=PoC_N(nsim=10000,n=150,mu=mu_gen[,13],sigma=1.478)
end_time <- Sys.time()
# Running time 5.8 hours
end_time - start_time

g0_N=cbind(n10g0_N,n25g0_N,n50g0_N,n75g0_N,n100g0_N,n150g0_N)
g1_N=cbind(n10g1_N,n25g1_N,n50g1_N,n75g1_N,n100g1_N,n150g1_N)
g2_N=cbind(n10g2_N,n25g2_N,n50g2_N,n75g2_N,n100g2_N,n150g2_N)
g3_N=cbind(n10g3_N,n25g3_N,n50g3_N,n75g3_N,n100g3_N,n150g3_N)
g4_N=cbind(n10g4_N,n25g4_N,n50g4_N,n75g4_N,n100g4_N,n150g4_N)
g5_N=cbind(n10g5_N,n25g5_N,n50g5_N,n75g5_N,n100g5_N,n150g5_N)
g6_N=cbind(n10g6_N,n25g6_N,n50g6_N,n75g6_N,n100g6_N,n150g6_N)
g7_N=cbind(n10g7_N,n25g7_N,n50g7_N,n75g7_N,n100g7_N,n150g7_N)
g8_N=cbind(n10g8_N,n25g8_N,n50g8_N,n75g8_N,n100g8_N,n150g8_N)
g9_N=cbind(n10g9_N,n25g9_N,n50g9_N,n75g9_N,n100g9_N,n150g9_N)
g10_N=cbind(n10g10_N,n25g10_N,n50g10_N,n75g10_N,n100g10_N,n150g10_N)
g11_N=cbind(n10g11_N,n25g11_N,n50g11_N,n75g11_N,n100g11_N,n150g11_N)
g12_N=cbind(n10g12_N,n25g12_N,n50g12_N,n75g12_N,n100g12_N,n150g12_N)
g13_N=cbind(n10g13_N,n25g13_N,n50g13_N,n75g13_N,n100g13_N,n150g13_N)

saveRDS(g0_N, file="g0_M6_Narrower.Rds")
saveRDS(g1_N, file="g1_M6_Narrower.Rds")
saveRDS(g2_N, file="g2_M6_Narrower.Rds")
saveRDS(g3_N, file="g3_M6_Narrower.Rds")
saveRDS(g4_N, file="g4_M6_Narrower.Rds")
saveRDS(g5_N, file="g5_M6_Narrower.Rds")
saveRDS(g6_N, file="g6_M6_Narrower.Rds")
saveRDS(g7_N, file="g7_M6_Narrower.Rds")
saveRDS(g8_N, file="g8_M6_Narrower.Rds")
saveRDS(g9_N, file="g9_M6_Narrower.Rds")
saveRDS(g10_N, file="g10_M6_Narrower.Rds")
saveRDS(g11_N, file="g11_M6_Narrower.Rds")
saveRDS(g12_N, file="g12_M6_Narrower.Rds")
saveRDS(g13_N, file="g13_M6_Narrower.Rds")

##############################################################################

start_time <- Sys.time()
#Wider candidate set of models
#Verify FWER
n10g0_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,14],sigma=1.478)
n25g0_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,14],sigma=1.478)
n50g0_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,14],sigma=1.478)
n75g0_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,14],sigma=1.478)
n100g0_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,14],sigma=1.478)
n150g0_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,14],sigma=1.478)

n10g1_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,1],sigma=1.478)
n25g1_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,1],sigma=1.478)
n50g1_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,1],sigma=1.478)
n75g1_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,1],sigma=1.478)
n100g1_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,1],sigma=1.478)
n150g1_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,1],sigma=1.478)

n10g2_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,2],sigma=1.478)
n25g2_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,2],sigma=1.478)
n50g2_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,2],sigma=1.478)
n75g2_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,2],sigma=1.478)
n100g2_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,2],sigma=1.478)
n150g2_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,2],sigma=1.478)

n10g3_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,3],sigma=1.478)
n25g3_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,3],sigma=1.478)
n50g3_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,3],sigma=1.478)
n75g3_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,3],sigma=1.478)
n100g3_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,3],sigma=1.478)
n150g3_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,3],sigma=1.478)

n10g4_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,4],sigma=1.478)
n25g4_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,4],sigma=1.478)
n50g4_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,4],sigma=1.478)
n75g4_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,4],sigma=1.478)
n100g4_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,4],sigma=1.478)
n150g4_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,4],sigma=1.478)

n10g5_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,5],sigma=1.478)
n25g5_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,5],sigma=1.478)
n50g5_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,5],sigma=1.478)
n75g5_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,5],sigma=1.478)
n100g5_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,5],sigma=1.478)
n150g5_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,5],sigma=1.478)

n10g6_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,6],sigma=1.478)
n25g6_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,6],sigma=1.478)
n50g6_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,6],sigma=1.478)
n75g6_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,6],sigma=1.478)
n100g6_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,6],sigma=1.478)
n150g6_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,6],sigma=1.478)

n10g7_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,7],sigma=1.478)
n25g7_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,7],sigma=1.478)
n50g7_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,7],sigma=1.478)
n75g7_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,7],sigma=1.478)
n100g7_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,7],sigma=1.478)
n150g7_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,7],sigma=1.478)

n10g8_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,8],sigma=1.478)
n25g8_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,8],sigma=1.478)
n50g8_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,8],sigma=1.478)
n75g8_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,8],sigma=1.478)
n100g8_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,8],sigma=1.478)
n150g8_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,8],sigma=1.478)

n10g9_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,9],sigma=1.478)
n25g9_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,9],sigma=1.478)
n50g9_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,9],sigma=1.478)
n75g9_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,9],sigma=1.478)
n100g9_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,9],sigma=1.478)
n150g9_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,9],sigma=1.478)

n10g10_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,10],sigma=1.478)
n25g10_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,10],sigma=1.478)
n50g10_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,10],sigma=1.478)
n75g10_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,10],sigma=1.478)
n100g10_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,10],sigma=1.478)
n150g10_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,10],sigma=1.478)

n10g11_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,11],sigma=1.478)
n25g11_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,11],sigma=1.478)
n50g11_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,11],sigma=1.478)
n75g11_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,11],sigma=1.478)
n100g11_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,11],sigma=1.478)
n150g11_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,11],sigma=1.478)

n10g12_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,12],sigma=1.478)
n25g12_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,12],sigma=1.478)
n50g12_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,12],sigma=1.478)
n75g12_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,12],sigma=1.478)
n100g12_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,12],sigma=1.478)
n150g12_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,12],sigma=1.478)

n10g13_W=PoC_W(nsim=10000,n=10,mu=mu_gen[,13],sigma=1.478)
n25g13_W=PoC_W(nsim=10000,n=25,mu=mu_gen[,13],sigma=1.478)
n50g13_W=PoC_W(nsim=10000,n=50,mu=mu_gen[,13],sigma=1.478)
n75g13_W=PoC_W(nsim=10000,n=75,mu=mu_gen[,13],sigma=1.478)
n100g13_W=PoC_W(nsim=10000,n=100,mu=mu_gen[,13],sigma=1.478)
n150g13_W=PoC_W(nsim=10000,n=150,mu=mu_gen[,13],sigma=1.478)
end_time <- Sys.time()
# Running time 5.2 hours
end_time - start_time

g0_W=cbind(n10g0_W,n25g0_W,n50g0_W,n75g0_W,n100g0_W,n150g0_W)
g1_W=cbind(n10g1_W,n25g1_W,n50g1_W,n75g1_W,n100g1_W,n150g1_W)
g2_W=cbind(n10g2_W,n25g2_W,n50g2_W,n75g2_W,n100g2_W,n150g2_W)
g3_W=cbind(n10g3_W,n25g3_W,n50g3_W,n75g3_W,n100g3_W,n150g3_W)
g4_W=cbind(n10g4_W,n25g4_W,n50g4_W,n75g4_W,n100g4_W,n150g4_W)
g5_W=cbind(n10g5_W,n25g5_W,n50g5_W,n75g5_W,n100g5_W,n150g5_W)
g6_W=cbind(n10g6_W,n25g6_W,n50g6_W,n75g6_W,n100g6_W,n150g6_W)
g7_W=cbind(n10g7_W,n25g7_W,n50g7_W,n75g7_W,n100g7_W,n150g7_W)
g8_W=cbind(n10g8_W,n25g8_W,n50g8_W,n75g8_W,n100g8_W,n150g8_W)
g9_W=cbind(n10g9_W,n25g9_W,n50g9_W,n75g9_W,n100g9_W,n150g9_W)
g10_W=cbind(n10g10_W,n25g10_W,n50g10_W,n75g10_W,n100g10_W,n150g10_W)
g11_W=cbind(n10g11_W,n25g11_W,n50g11_W,n75g11_W,n100g11_W,n150g11_W)
g12_W=cbind(n10g12_W,n25g12_W,n50g12_W,n75g12_W,n100g12_W,n150g12_W)
g13_W=cbind(n10g13_W,n25g13_W,n50g13_W,n75g13_W,n100g13_W,n150g13_W)

saveRDS(g0_W, file="g0_M6_Wider.Rds")
saveRDS(g1_W, file="g1_M6_Wider.Rds")
saveRDS(g2_W, file="g2_M6_Wider.Rds")
saveRDS(g3_W, file="g3_M6_Wider.Rds")
saveRDS(g4_W, file="g4_M6_Wider.Rds")
saveRDS(g5_W, file="g5_M6_Wider.Rds")
saveRDS(g6_W, file="g6_M6_Wider.Rds")
saveRDS(g7_W, file="g7_M6_Wider.Rds")
saveRDS(g8_W, file="g8_M6_Wider.Rds")
saveRDS(g9_W, file="g9_M6_Wider.Rds")
saveRDS(g10_W, file="g10_M6_Wider.Rds")
saveRDS(g11_W, file="g11_M6_Wider.Rds")
saveRDS(g12_W, file="g12_M6_Wider.Rds")
saveRDS(g13_W, file="g13_M6_Wider.Rds")

########################################################
### Generate Figure 2 and 3
########################################################

g0_N=readRDS(file="g0_M6_Narrower.Rds")
g1_N=readRDS(file="g1_M6_Narrower.Rds")
g2_N=readRDS(file="g2_M6_Narrower.Rds")
g3_N=readRDS(file="g3_M6_Narrower.Rds")
g4_N=readRDS(file="g4_M6_Narrower.Rds")
g5_N=readRDS(file="g5_M6_Narrower.Rds")
g6_N=readRDS(file="g6_M6_Narrower.Rds")
g7_N=readRDS(file="g7_M6_Narrower.Rds")
g8_N=readRDS(file="g8_M6_Narrower.Rds")
g9_N=readRDS(file="g9_M6_Narrower.Rds")
g10_N=readRDS(file="g10_M6_Narrower.Rds")
g11_N=readRDS(file="g11_M6_Narrower.Rds")
g12_N=readRDS(file="g12_M6_Narrower.Rds")
g13_N=readRDS(file="g13_M6_Narrower.Rds")

g0_W=readRDS(file="g0_M6_Wider.Rds")
g1_W=readRDS(file="g1_M6_Wider.Rds")
g2_W=readRDS(file="g2_M6_Wider.Rds")
g3_W=readRDS(file="g3_M6_Wider.Rds")
g4_W=readRDS(file="g4_M6_Wider.Rds")
g5_W=readRDS(file="g5_M6_Wider.Rds")
g6_W=readRDS(file="g6_M6_Wider.Rds")
g7_W=readRDS(file="g7_M6_Wider.Rds")
g8_W=readRDS(file="g8_M6_Wider.Rds")
g9_W=readRDS(file="g9_M6_Wider.Rds")
g10_W=readRDS(file="g10_M6_Wider.Rds")
g11_W=readRDS(file="g11_M6_Wider.Rds")
g12_W=readRDS(file="g12_M6_Wider.Rds")
g13_W=readRDS(file="g13_M6_Wider.Rds")

#Consider 9 data generating functions in the plots, they are:
#Emax (g1), Linear in log (dose) (g2), Linear (g3), E1 (g4), Q1 (g6), 
#Logistic (g8), Double-logistic (g9), Step 2 (g11), Step 3 (g12)
#Only draw n=25,50,75 and 100
gg1_N=g1_N[,2:5]
gg2_N=g2_N[,2:5]
gg3_N=g3_N[,2:5]
gg4_N=g4_N[,2:5]
gg5_N=g6_N[,2:5]
gg6_N=g8_N[,2:5]
gg7_N=g9_N[,2:5]
gg8_N=g11_N[,2:5]
gg9_N=g12_N[,2:5]

gg1_W=g1_W[,2:5]
gg2_W=g2_W[,2:5]
gg3_W=g3_W[,2:5]
gg4_W=g4_W[,2:5]
gg5_W=g6_W[,2:5]
gg6_W=g8_W[,2:5]
gg7_W=g9_W[,2:5]
gg8_W=g11_W[,2:5]
gg9_W=g12_W[,2:5]


postscript("MA_AND_MCDERMOTT_Figure2.eps", onefile=F, paper="special", height=14, width=15, horizontal=F)
par(mfrow=c(3,3))
####Narrower Candidate Set####
plot(1:4, gg1_N[1,],typ='l',ylim=c(0.44,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Emax',xaxt='n')
points(1:4, gg1_N[1,])
lines(1:4, gg1_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg1_N[2,])
lines(1:4, gg1_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg1_N[3,])
lines(1:4, gg1_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg1_N[4,])
lines(1:4, gg1_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg1_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg2_N[1,],typ='l',ylim=c(0.45,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Linear in log (dose)',xaxt='n')
points(1:4, gg2_N[1,])
lines(1:4, gg2_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg2_N[2,])
lines(1:4, gg2_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg2_N[3,])
lines(1:4, gg2_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg2_N[4,])
lines(1:4, gg2_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg2_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg3_N[1,],typ='l',ylim=c(0.45,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Linear',xaxt='n')
points(1:4, gg3_N[1,])
lines(1:4, gg3_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg3_N[2,])
lines(1:4, gg3_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg3_N[3,])
lines(1:4, gg3_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg3_N[4,])
lines(1:4, gg3_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg3_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))

plot(1:4, gg4_N[1,],typ='l',ylim=c(0.4,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Exponential 1',xaxt='n')
points(1:4, gg4_N[1,])
lines(1:4, gg4_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg4_N[2,])
lines(1:4, gg4_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg4_N[3,])
lines(1:4, gg4_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg4_N[4,])
lines(1:4, gg4_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg4_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg5_N[1,],typ='l',ylim=c(0.3,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Quadratic 1',xaxt='n')
points(1:4, gg5_N[1,])
lines(1:4, gg5_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg5_N[2,])
lines(1:4, gg5_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg5_N[3,])
lines(1:4, gg5_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg5_N[4,])
lines(1:4, gg5_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg5_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg6_N[1,],typ='l',ylim=c(0.5,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Logistic',xaxt='n')
points(1:4, gg6_N[1,])
lines(1:4, gg6_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg6_N[2,])
lines(1:4, gg6_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg6_N[3,])
lines(1:4, gg6_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg6_N[4,])
lines(1:4, gg6_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg6_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg7_N[1,],typ='l',ylim=c(0.3,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Double-logistic',xaxt='n')
points(1:4, gg7_N[1,])
lines(1:4, gg7_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg7_N[2,])
lines(1:4, gg7_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg7_N[3,])
lines(1:4, gg7_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg7_N[4,])
lines(1:4, gg7_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg7_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))



plot(1:4, gg8_N[1,],typ='l',ylim=c(0.55,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Step 2',xaxt='n')
points(1:4, gg8_N[1,])
lines(1:4, gg8_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg8_N[2,])
lines(1:4, gg8_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg8_N[3,])
lines(1:4, gg8_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg8_N[4,])
lines(1:4, gg8_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg8_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))



plot(1:4, gg9_N[1,],typ='l',ylim=c(0.55,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Step 3',xaxt='n')
points(1:4, gg9_N[1,])
lines(1:4, gg9_N[2,],col='red',lwd=2,lty=4)
points(1:4, gg9_N[2,])
lines(1:4, gg9_N[3,],col='blue',lty=3,lwd=2)
points(1:4, gg9_N[3,])
lines(1:4, gg9_N[4,],col='pink',lty=4,lwd=2)
points(1:4, gg9_N[4,])
lines(1:4, gg9_N[5,],col='black',lty=5,lwd=2)
points(1:4,gg9_N[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))

dev.off()

#############################################################################

####Wider Candidate Set####
postscript("MA_AND_MCDERMOTT_Figure3.eps", onefile=F, paper="special", height=14, width=15, horizontal=F)
par(mfrow=c(3,3))
plot(1:4, gg1_W[1,],typ='l',ylim=c(0.4,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Emax',xaxt='n')
points(1:4, gg1_W[1,])
lines(1:4, gg1_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg1_W[2,])
lines(1:4, gg1_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg1_W[3,])
lines(1:4, gg1_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg1_W[4,])
lines(1:4, gg1_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg1_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg2_W[1,],typ='l',ylim=c(0.4,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Linear in log (dose)',xaxt='n')
points(1:4, gg2_W[1,])
lines(1:4, gg2_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg2_W[2,])
lines(1:4, gg2_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg2_W[3,])
lines(1:4, gg2_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg2_W[4,])
lines(1:4, gg2_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg2_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg3_W[1,],typ='l',ylim=c(0.4,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Linear',xaxt='n')
points(1:4, gg3_W[1,])
lines(1:4, gg3_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg3_W[2,])
lines(1:4, gg3_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg3_W[3,])
lines(1:4, gg3_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg3_W[4,])
lines(1:4, gg3_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg3_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))

plot(1:4, gg4_W[1,],typ='l',ylim=c(0.3,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Exponential 1',xaxt='n')
points(1:4, gg4_W[1,])
lines(1:4, gg4_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg4_W[2,])
lines(1:4, gg4_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg4_W[3,])
lines(1:4, gg4_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg4_W[4,])
lines(1:4, gg4_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg4_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))

plot(1:4, gg5_W[1,],typ='l',ylim=c(0.3,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Quadratic 1',xaxt='n')
points(1:4, gg5_W[1,])
lines(1:4, gg5_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg5_W[2,])
lines(1:4, gg5_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg5_W[3,])
lines(1:4, gg5_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg5_W[4,])
lines(1:4, gg5_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg5_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg6_W[1,],typ='l',ylim=c(0.5,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Logistic',xaxt='n')
points(1:4, gg6_W[1,])
lines(1:4, gg6_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg6_W[2,])
lines(1:4, gg6_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg6_W[3,])
lines(1:4, gg6_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg6_W[4,])
lines(1:4, gg6_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg6_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg7_W[1,],typ='l',ylim=c(0.3,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Double-logistic',xaxt='n')
points(1:4, gg7_W[1,])
lines(1:4, gg7_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg7_W[2,])
lines(1:4, gg7_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg7_W[3,])
lines(1:4, gg7_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg7_W[4,])
lines(1:4, gg7_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg7_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg8_W[1,],typ='l',ylim=c(0.55,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Step 2',xaxt='n')
points(1:4, gg8_W[1,])
lines(1:4, gg8_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg8_W[2,])
lines(1:4, gg8_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg8_W[3,])
lines(1:4, gg8_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg8_W[4,])
lines(1:4, gg8_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg8_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))


plot(1:4, gg9_W[1,],typ='l',ylim=c(0.53,1),xlab='Sample size per group',ylab='Power',
     col='green',lwd=2,lty=6,
     main='Step 3',xaxt='n')
points(1:4, gg9_W[1,])
lines(1:4, gg9_W[2,],col='red',lwd=2,lty=4)
points(1:4, gg9_W[2,])
lines(1:4, gg9_W[3,],col='blue',lty=3,lwd=2)
points(1:4, gg9_W[3,])
lines(1:4, gg9_W[4,],col='pink',lty=4,lwd=2)
points(1:4, gg9_W[4,])
lines(1:4, gg9_W[5,],col='black',lty=5,lwd=2)
points(1:4,gg9_W[5,])
legend("bottomright", c("MCP-Mod", "F", "N",
                        "LRT", "Step"),lty=c(6,2,3,4,5),
       lwd=c(2,2,2,2,2),bty = "n",cex=0.7,
       col=c('green','red','blue','pink','black')) 
axis(1, 1:4, labels=c(25,50,75,100))

dev.off()